@@ -177,11 +177,11 @@ class TestGroup(unittest.TestCase):
 
         # testing "size" property
         # getter
-        self.assertEqual(g.size, (1.0, 1.0))
-        self.assertEqual(g.width, 1.0)
-        self.assertEqual(g.height, 1.0)
+        self.assertEqual(g.size, (2.0, 2.0))
+        self.assertEqual(g.width, 2.0)
+        self.assertEqual(g.height, 2.0)
 
-        img.position = (0.0, 0.0, 0.0)
+        img.position = (0, 0, 0)
         self.assertEqual(g.size, (2.0, 2.0))
         self.assertEqual(g.width, 2.0)
         self.assertEqual(g.height, 2.0)
@@ -700,3 +700,21 @@ class TestGroup(unittest.TestCase):
         self.assertEqual(g_parent.canvas, canvas)
         self.assertEqual(g_child.canvas, canvas)
         self.assertEqual(img.get_parent(), canvas)
+
+    def test_size_with_offset(self):
+        group = Group()
+        img1 = Image()
+        img1.size = (1, 2)
+
+        group.add(img1)
+        self.assertEqual(group.size, (1, 2))
+
+        img1.position = (1, 0, 0)
+        self.assertEqual(group.size, (2, 2))
+
+        img1.position = (0, 1, 0)
+        self.assertEqual(group.size, (1, 3))
+
+        img1.position = (1, 1, 1)
+        self.assertEqual(group.size, (2, 3))
+
